"""Nile plugin adding coverage reports for Cairo Smart Contracts."""
import logging

__author__ = "Eric Nordelo"
__copyright__ = "Eric Nordelo"
__license__ = "MIT"

logger = logging.getLogger(__name__)



"""Coverage command definition."""

import click
import pytest

from nile_coverage import logger
from nile_coverage.pytest_plugins.coverage import CoveragePlugin


@click.command()
@click.option("--mark", "-m", help="pytest mark")
def coverage():
    """Generate coverage report for Cairo Smart Contracts."""
    logger.info("\nGenerating coverage report")

    args = ["-p", "no:warnings"]

    if mark is not None:
        args += ["-m", mark]

    pytest.main(args, plugins=[CoveragePlugin()])



"""PyTest plugin to print coverage report."""
from nile_coverage.vendor import cairo_coverage


class CoveragePlugin:
    def pytest_sessionfinish(self):
        """
        Called after whole test run finished, right before
        returning the exit status to the system.
        """
        cairo_coverage.report_runs()
